@@ -451,22 +451,9 @@ class Builder(object):
         for lookup in self.lookups_:
             lookup.lookup_index = None
         lookups = []
-        for i, lookup in enumerate(self.lookups_):
+        for lookup in self.lookups_:
             if lookup.table != tag:
                 continue
-            # TODO: https://github.com/behdad/fonttools/issues/448
-            # If multiple lookup builders would build equivalent lookups,
-            # emit them only once. This is quadratic in the number of lookups,
-            # but the checks are cheap. If performance ever becomes an issue,
-            # we could hash the lookup content and only compare those with
-            # the same hash value.
-            equivalent = None
-            for other in self.lookups_[:i]:
-                if lookup.equals(other):
-                    equivalent = other
-            if equivalent is not None:
-                lookup.lookup_index = equivalent.lookup_index
-                continue
             lookup.lookup_index = len(lookups)
             lookups.append(lookup)
         return [l.build() for l in lookups]
@@ -887,6 +874,13 @@ class Builder(object):
                         otMarkAnchor = makeOpenTypeAnchor(markClassDef.anchor)
                         lookupBuilder.marks[mark] = (
                             markClass.name, otMarkAnchor)
+                    else:
+                        existingMarkClass = lookupBuilder.marks[mark][0]
+                        if markClass.name != existingMarkClass:
+                            raise FeatureLibError(
+                                "Glyph %s cannot be in both @%s and @%s" % (
+                                    mark, existingMarkClass, markClass.name),
+                                location)
 
     def add_mark_base_pos(self, location, bases, marks):
         builder = self.get_lookup_(location, MarkBasePosBuilder)
@@ -1380,7 +1374,6 @@ class ClassPairPosSubtableBuilder(object):
     def __init__(self, builder, valueFormat1, valueFormat2):
         self.builder_ = builder
         self.classDef1_, self.classDef2_ = None, None
-        self.coverage_ = set()
         self.values_ = {}  # (glyphclass1, glyphclass2) --> (value1, value2)
         self.valueFormat1_, self.valueFormat2_ = valueFormat1, valueFormat2
         self.forceSubtableBreak_ = False
@@ -1396,11 +1389,9 @@ class ClassPairPosSubtableBuilder(object):
             self.flush_()
             self.classDef1_ = otl.ClassDefBuilder(useClass0=True)
             self.classDef2_ = otl.ClassDefBuilder(useClass0=False)
-            self.coverage_ = set()
             self.values_ = {}
         self.classDef1_.add(gc1)
         self.classDef2_.add(gc2)
-        self.coverage_.update(gc1)
         self.values_[(gc1, gc2)] = (value1, value2)
 
     def addSubtableBreak(self):
