@@ -31,8 +31,8 @@ log = logging.getLogger(__name__)
 
 class TupleVariation(object):
 	def __init__(self, axes, coordinates):
-		self.axes = axes
-		self.coordinates = coordinates
+		self.axes = axes.copy()
+		self.coordinates = coordinates[:]
 
 	def __repr__(self):
 		axes = ",".join(sorted(["%s=%s" % (name, value) for (name, value) in self.axes.items()]))
