@@ -1,6 +1,7 @@
 """_g_l_y_f.py -- Converter classes for the 'glyf' table."""
 
 from __future__ import print_function, division, absolute_import
+from collections import namedtuple
 from fontTools.misc.py23 import *
 from fontTools.misc import sstruct
 from fontTools import ttLib
@@ -297,6 +298,9 @@ SCALED_COMPONENT_OFFSET		= 0x0800  # composite designed to have the component of
 UNSCALED_COMPONENT_OFFSET	= 0x1000  # composite designed not to have the component offset scaled (designed for MS)
 
 
+CompositeMaxpValues = namedtuple('CompositeMaxpValues', ['nPoints', 'nContours', 'maxComponentDepth'])
+
+
 class Glyph(object):
 
 	def __init__(self, data=""):
@@ -354,11 +358,7 @@ class Glyph(object):
 		if self.isComposite():
 			for compo in self.components:
 				compo.toXML(writer, ttFont)
-			if hasattr(self, "program"):
-				writer.begintag("instructions")
-				self.program.toXML(writer, ttFont)
-				writer.endtag("instructions")
-				writer.newline()
+			haveInstructions = hasattr(self, "program")
 		else:
 			last = 0
 			for i in range(self.numberOfContours):
@@ -373,11 +373,16 @@ class Glyph(object):
 				last = self.endPtsOfContours[i] + 1
 				writer.endtag("contour")
 				writer.newline()
-			if self.numberOfContours:
+			haveInstructions = self.numberOfContours > 0
+		if haveInstructions:
+			if self.program:
 				writer.begintag("instructions")
+				writer.newline()
 				self.program.toXML(writer, ttFont)
 				writer.endtag("instructions")
-				writer.newline()
+			else:
+				writer.simpletag("instructions")
+			writer.newline()
 
 	def fromXML(self, name, attrs, content, ttFont):
 		if name == "contour":
@@ -435,7 +440,7 @@ class Glyph(object):
 						glyfTable, maxComponentDepth + 1)
 			nPoints = nPoints + nP
 			nContours = nContours + nC
-		return nPoints, nContours, maxComponentDepth
+		return CompositeMaxpValues(nPoints, nContours, maxComponentDepth)
 
 	def getMaxpValues(self):
 		assert self.numberOfContours > 0
@@ -1160,14 +1165,18 @@ class GlyphCoordinates(object):
 		self._a = array.array(typecode)
 		self.extend(iterable)
 
+	@property
+	def array(self):
+		return self._a
+
 	def isFloat(self):
-		return self._a.typecode == 'f'
+		return self._a.typecode == 'd'
 
 	def _ensureFloat(self):
 		if self.isFloat():
 			return
 		# The conversion to list() is to work around Jython bug
-		self._a = array.array("f", list(self._a))
+		self._a = array.array("d", list(self._a))
 
 	def _checkFloat(self, p):
 		if self.isFloat():
@@ -1346,22 +1355,6 @@ class GlyphCoordinates(object):
 		for i in range(len(a)):
 			a[i] = -a[i]
 		return r
-	def __abs__(self):
-		"""
-		>>> g = GlyphCoordinates([(-1.5,2)])
-		>>> g
-		GlyphCoordinates([(-1.5, 2.0)])
-		>>> g2 = abs(g)
-		>>> g
-		GlyphCoordinates([(-1.5, 2.0)])
-		>>> g2
-		GlyphCoordinates([(1.5, 2.0)])
-		"""
-		r = self.copy()
-		a = r._a
-		for i in range(len(a)):
-			a[i] = abs(a[i])
-		return r
 	def __round__(self):
 		"""
 		Note: This is Python 3 only.  Python 2 does not call __round__.
@@ -1470,6 +1463,25 @@ class GlyphCoordinates(object):
 			return self
 		return NotImplemented
 
+	def __bool__(self):
+		"""
+		>>> g = GlyphCoordinates([])
+		>>> bool(g)
+		False
+		>>> g = GlyphCoordinates([(0,0), (0.,0)])
+		>>> bool(g)
+		True
+		>>> g = GlyphCoordinates([(0,0), (1,0)])
+		>>> bool(g)
+		True
+		>>> g = GlyphCoordinates([(0,.5), (0,0)])
+		>>> bool(g)
+		True
+		"""
+		return bool(self._a)
+
+	__nonzero__ = __bool__
+
 
 def reprflag(flag):
 	bin = ""
