@@ -99,7 +99,7 @@ class Merger(object):
 			e.args = e.args + (clazz.__name__,)
 			raise
 
-	def mergeTables(self, font, master_ttfs, axes, base_idx, tables):
+	def mergeTables(self, font, master_ttfs, tables):
 
 		for tag in tables:
 			if tag not in font: continue
@@ -294,7 +294,10 @@ def _PairPosFormat1_merge(self, lst, merger):
 
 def _ClassDef_invert(self, allGlyphs=None):
 
-	classDefs = self.classDefs if self and self.classDefs else {}
+	if isinstance(self, dict):
+		classDefs = self
+	else:
+		classDefs = self.classDefs if self and self.classDefs else {}
 	m = max(classDefs.values()) if classDefs else 0
 
 	ret = []
@@ -308,9 +311,12 @@ def _ClassDef_invert(self, allGlyphs=None):
 	if allGlyphs is None:
 		ret[0] = None
 	else:
-		ret[0] = set(allGlyphs)
+		# Limit all classes to glyphs in allGlyphs.
+		# Collect anything without a non-zero class into class=zero.
+		ret[0] = class0 = set(allGlyphs)
 		for s in ret[1:]:
-			ret[0].difference_update(s)
+			s.intersection_update(class0)
+			class0.difference_update(s)
 
 	return ret
 
@@ -575,13 +581,13 @@ def _Lookup_PairPos_subtables_canonicalize(lst, font):
 
 	for subtable in it:
 		oldtable = tail[-1]
-		if oldtable.Format == 2 and subtable.Format == 2:
-			if (oldtable.Class2Count == subtable.Class2Count and
-			    oldtable.ClassDef2.classDefs == subtable.ClassDef2.classDefs and
-			    oldtable.ValueFormat1 == subtable.ValueFormat1 and
-			    oldtable.ValueFormat2 == subtable.ValueFormat2):
-				newtable = _Lookup_PairPosFormat2_subtables_recombine(oldtable, subtable, font)
-				tail[-1] = newtable
+		if (oldtable.Format == 2 and subtable.Format == 2 and
+		    oldtable.Class2Count == subtable.Class2Count and
+		    oldtable.ClassDef2.classDefs == subtable.ClassDef2.classDefs and
+		    oldtable.ValueFormat1 == subtable.ValueFormat1 and
+		    oldtable.ValueFormat2 == subtable.ValueFormat2):
+			newtable = _Lookup_PairPosFormat2_subtables_recombine(oldtable, subtable, font)
+			tail[-1] = newtable
 			continue
 		tail.append(subtable)
 
@@ -624,20 +630,21 @@ class InstancerMerger(AligningMerger):
 		Merger.__init__(self, font)
 		self.model = model
 		self.location = location
+		self.scalars = model.getScalars(location)
 
 @InstancerMerger.merger(ot.Anchor)
 def merge(merger, self, lst):
 	XCoords = [a.XCoordinate for a in lst]
 	YCoords = [a.YCoordinate for a in lst]
 	model = merger.model
-	location = merger.location
-	self.XCoordinate = round(model.interpolateFromMasters(location, XCoords))
-	self.YCoordinate = round(model.interpolateFromMasters(location, YCoords))
+	scalars = merger.scalars
+	self.XCoordinate = round(model.interpolateFromMastersAndScalars(XCoords, scalars))
+	self.YCoordinate = round(model.interpolateFromMastersAndScalars(YCoords, scalars))
 
 @InstancerMerger.merger(otBase.ValueRecord)
 def merge(merger, self, lst):
 	model = merger.model
-	location = merger.location
+	scalars = merger.scalars
 	# TODO Handle differing valueformats
 	for name, tableName in [('XAdvance','XAdvDevice'),
 				('YAdvance','YAdvDevice'),
@@ -648,7 +655,7 @@ def merge(merger, self, lst):
 
 		if hasattr(self, name):
 			values = [getattr(a, name, 0) for a in lst]
-			value = round(model.interpolateFromMasters(location, values))
+			value = round(model.interpolateFromMastersAndScalars(values, scalars))
 			setattr(self, name, value)
 
 
